Changelog
=========

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/), and this project adheres to
[Semantic Versioning](https://semver.org/spec/v2.0.0.html).

v0.2 - 2024-07-02
-----------------

Removes the dependency on allow- and deny-list files and manages this feature through the UI.

### Added

- Pluggable allow- and deny-list filters (@sidneys1).
- UI management for the deny-list, allow-list entries, and their filters (@sidneys1).

### Removed

- The old file-base allow- and deny-list filters.


v0.1 - 2024-06-06
-----------------

Initial project commit, basic functionality intact.

### Added

- All base functionality.
- GitHub Actions to build and publish Python packages and container images.

<!--------------------------------------------------------------------------------------------------------------------->

<!--
{version}
---------

General description of this release.

Any additional notes for this release.

### Added

<!~~ List of things that have been added. Be sure to @mention contributors, #tag relevant discussions/issues/PRs. ~~>
- A changelog (@sidneys1).

### Changed
### Deprecated
### Removed
### Fixed
### Security
-->
